Module editor
raster
0.2.0
Module editor
Module Items
Enums
Functions
In crate raster
raster
Module
editor
A module for common image editing operations.
Enums

Resize
Mode
An enum for the various modes that can be used for resizing.
Functions

blend
Blend 2 images into one. The image1 is the base and image2 is the top.
crop
Crop the image to the given dimension and position.
fill
Fill an image with color.
resize
Resize an image to a given width, height and mode.